##  Overview
Application portfolio assessment enables you to identify dependencies and optimization potential for your applications, achieve data transparency, and support informed decision-making. By bringing data into SAP LeanIX and establishing data governance processes, you can address challenges that result from storing data in multiple tools, such as data silos, redundancy, and inefficiencies.
In this step-by-step guide, you'll learn how to conduct an initial application portfolio assessment with a limited data set. The steps you perform, such as importing and maintaining data, are essential and ongoing tasks for effective architectural governance. After your initial assessment, you can add more fact sheets and introduce additional fact sheet types as your inventory matures. You can also proceed to more advanced use cases, such as application rationalization and modernization.
